@@ -24,13 +24,15 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include "H264VideoStreamDiscreteFramer.hh"
 
 H264VideoStreamDiscreteFramer*
-H264VideoStreamDiscreteFramer::createNew(UsageEnvironment& env, FramedSource* inputSource) {
-  return new H264VideoStreamDiscreteFramer(env, inputSource);
+H264VideoStreamDiscreteFramer::createNew(UsageEnvironment& env, FramedSource* inputSource,
+					 Boolean includeStartCodeInOutput) {
+  return new H264VideoStreamDiscreteFramer(env, inputSource, includeStartCodeInOutput);
 }
 
 H264VideoStreamDiscreteFramer
-::H264VideoStreamDiscreteFramer(UsageEnvironment& env, FramedSource* inputSource)
-  : H264or5VideoStreamDiscreteFramer(264, env, inputSource) {
+::H264VideoStreamDiscreteFramer(UsageEnvironment& env, FramedSource* inputSource,
+				Boolean includeStartCodeInOutput)
+  : H264or5VideoStreamDiscreteFramer(264, env, inputSource, includeStartCodeInOutput) {
 }
 
 H264VideoStreamDiscreteFramer::~H264VideoStreamDiscreteFramer() {
