@@ -894,11 +894,11 @@ void H264or5VideoStreamParser
       unsigned dpb_output_delay = bv.getBits(dpb_output_delay_length_minus1 + 1);
       DEBUG_PRINT(dpb_output_delay);
     }
+    double prevDeltaTfiDivisor = DeltaTfiDivisor; 
     if (pic_struct_present_flag) {
       unsigned pic_struct = bv.getBits(4);
       DEBUG_PRINT(pic_struct);
       // Use this to set "DeltaTfiDivisor" (which is used to compute the frame rate):
-      double prevDeltaTfiDivisor = DeltaTfiDivisor; 
       if (fHNumber == 264) {
 	DeltaTfiDivisor =
 	  pic_struct == 0 ? 2.0 :
@@ -919,16 +919,22 @@ void H264or5VideoStreamParser
 	  pic_struct <= 12 ? 1.0 :
 	  2.0;
       }
-      // If "DeltaTfiDivisor" has changed, and we've already computed the frame rate, then
-      // adjust it, based on the new value of "DeltaTfiDivisor":
-      if (DeltaTfiDivisor != prevDeltaTfiDivisor && fParsedFrameRate != 0.0) {
-	  usingSource()->fFrameRate = fParsedFrameRate
-	    = fParsedFrameRate*(prevDeltaTfiDivisor/DeltaTfiDivisor);
-#ifdef DEBUG
-	  fprintf(stderr, "Changed frame rate to %f fps\n", usingSource()->fFrameRate);
-#endif
+    } else {
+      if (fHNumber == 264) {
+	// Need to get field_pic_flag from slice_header to set this properly! #####
+      } else { // H.265
+	DeltaTfiDivisor = 1;
       }
     }
+    // If "DeltaTfiDivisor" has changed, and we've already computed the frame rate, then
+    // adjust it, based on the new value of "DeltaTfiDivisor":
+    if (DeltaTfiDivisor != prevDeltaTfiDivisor && fParsedFrameRate != 0.0) {
+      usingSource()->fFrameRate = fParsedFrameRate
+	= fParsedFrameRate*(prevDeltaTfiDivisor/DeltaTfiDivisor);
+#ifdef DEBUG
+      fprintf(stderr, "Changed frame rate to %f fps\n", usingSource()->fFrameRate);
+#endif
+    }
     // Ignore the rest of the payload (timestamps) for now... #####
   }
 }
